from pathlib import Path
from datetime import datetime, timedelta
import re
from inspect import cleandoc
from base64 import b64encode

from jinja2 import Environment, FileSystemLoader, select_autoescape
from ansi2html import Ansi2HTMLConverter
from ansi2html.style import get_styles
from docutils.core import publish_parts
import htmlmin


TEMPLATE_PATH = Path(__file__).parent / "templates"
ICONS_PATH = TEMPLATE_PATH / "html1" / "icons"


def pytest_reporter_context(context, config):
    # category/style: background-color, color
    context.setdefault("colors", {
        "passed": ("#43A047", "#FFFFFF"),
        "failed": ("#F44336", "#FFFFFF"),
        "error": ("#B71C1C", "#FFFFFF"),
        "xfailed": ("#EF9A9A", "#333333"),
        "xpassed": ("#A5D6A7", "#333333"),
        "skipped": ("#9E9E9E", "#FFFFFF"),
        "warning": ("#FBC02D", "#333333"),
        "green": ("#43A047", "#FFFFFF"),
        "red": ("#E53935", "#FFFFFF"),
        "yellow": ("#FBC02D", "#333333"),
    })

def pytest_reporter_render(template_name, dirs, context):
    conv = Ansi2HTMLConverter(escaped=False)
    env = Environment(
        loader=FileSystemLoader(dirs + [str(TEMPLATE_PATH)]),
        autoescape=select_autoescape(["html", "htm", "xml"]),
    )
    env.globals["icons"] = {
        icon.stem: (
            "data:image/svg+xml;base64," +
            b64encode(icon.read_bytes()).decode("utf-8")
        ) for icon in ICONS_PATH.glob("*.svg")
    }
    env.globals["get_ansi_styles"] = get_styles
    env.filters["repr"] = repr
    env.filters["strftime"] = lambda ts, fmt: datetime.fromtimestamp(ts).strftime(fmt)
    env.filters["timedelta"] = lambda ts: timedelta(seconds=ts)
    env.filters["ansi"] = lambda s: conv.convert(s, full=False)
    env.filters["cleandoc"] = cleandoc
    env.filters["rst"] = lambda s: publish_parts(source=s, writer_name="html5")["body"]
    env.filters["css_minify"] = lambda s: re.sub(r"\s+", " ", s)

    try:
        template = env.get_template(template_name)
    except TemplateNotFound:
        return
    html = template.render(context)
    minified = htmlmin.minify(html, remove_comments=True)
    return minified



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import codecs
from setuptools import setup, find_packages


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return codecs.open(file_path, encoding='utf-8').read()


setup(
    name='pytest-reporter-html1',
    version='0.1.0',
    author='Christian Sandberg',
    author_email='christiansandberg@me.com',
    maintainer='Christian Sandberg',
    maintainer_email='christiansandberg@me.com',
    license='MIT',
    url='https://github.com/christiansandberg/pytest-reporter-html1',
    description='A basic HTML report template for Pytest',
    long_description=read('README.rst'),
    packages=find_packages(),
    package_data={'pytest_reporter_html1': ['templates/html1/*']},
    include_package_data=True,
    python_requires='>=3.5',
    install_requires=[
        'pytest-reporter>=0.1.0',
        'Jinja2',
        'ansi2html>=1.3.0',
        'htmlmin',
        'docutils',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Pytest',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Testing',
        'Topic :: Text Processing :: Markup :: HTML',
        'Programming Language :: Python',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
    ],
    entry_points={
        'pytest11': [
            'reporter_html1 = pytest_reporter_html1.plugin',
        ],
    },
)
